﻿using Microsoft.Extensions.Logging;
using SushiContracts.BindingModels;
using SushiContracts.BusinessLogicContracts;
using SushiContracts.BusinessLogicsContracts;
using SushiContracts.SearchModels;

namespace Sushi
{
    public partial class FormCreateOrder : Form
    {
        private readonly ILogger _logger;
        private readonly ISushiLogic _logicS;
        private readonly IOrderLogic _logicO;
        private readonly IClientLogic _logicC;
        private readonly IEmployeeLogic _logicE;
        private int? _id;
        public int Id { set { _id = value; } }
        public FormCreateOrder(ILogger<FormCreateOrder> logger, ISushiLogic logicS, IOrderLogic logicO, IClientLogic logicC, IEmployeeLogic logicE)
        {
            InitializeComponent();
            _logger = logger;
            _logicS = logicS;
            _logicO = logicO;
            _logicC = logicC;
            _logicE = logicE;
        }
        private void FormCreateOrder_Load(object sender, EventArgs e)
        {
            _logger.LogInformation("Загрузка блюда для заказа");
            try
            {
                var list = _logicS.ReadList(null);
                if (list != null)
                {
                    comboBoxSushi.DisplayMember = "SushiName";
                    comboBoxSushi.ValueMember = "Id";
                    comboBoxSushi.DataSource = list;
                    comboBoxSushi.SelectedItem = null;
                }
                var listC = _logicC.ReadList(null);
                if (listC != null)
                {
                    comboBoxClient.DisplayMember = "ClientName";
                    comboBoxClient.ValueMember = "Id";
                    comboBoxClient.DataSource = listC;
                    comboBoxClient.SelectedItem = null;
                }
                var listE = _logicE.ReadList(null);
                if (listE != null)
                {
                    comboBoxEmployee.DisplayMember = "EmployeeName";
                    comboBoxEmployee.ValueMember = "Id";
                    comboBoxEmployee.DataSource = listE;
                    comboBoxEmployee.SelectedItem = null;
                }
                _logger.LogInformation("Блюдо загружено");
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка загрузки блюда");
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK,
               MessageBoxIcon.Error);
            }
        }
        private void CalcSum()
        {
            if (comboBoxSushi.SelectedValue != null &&
           !string.IsNullOrEmpty(textBoxCount.Text))
            {
                try
                {
                    int id = Convert.ToInt32(comboBoxSushi.SelectedValue);
                    var repair = _logicS.ReadElement(new SushiSearchModel
                    {
                        Id = id
                    });
                    int count = Convert.ToInt32(textBoxCount.Text);
                    textBoxSum.Text = Math.Round(count * (repair?.Price ?? 0), 2).ToString();
                    _logger.LogInformation("Расчет суммы заказа");
                }
                catch (Exception ex)
                {
                    _logger.LogError(ex, "Ошибка расчета суммы заказа");
                    MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK,
                    MessageBoxIcon.Error);
                }
            }
        }
        private void TextBoxCount_TextChanged(object sender, EventArgs e)
        {
            CalcSum();
        }
        private void TextBoxSum_TextChanged(object sender, EventArgs e)
        {
            CalcSum();
        }
        private void ComboBoxRepair_SelectedIndexChanged(object sender, EventArgs e)
        {
            CalcSum();
        }
        private void ButtonSave_Click(object sender, EventArgs e)
        {
            if (comboBoxSushi.SelectedValue == null || comboBoxClient.SelectedValue == null || comboBoxEmployee.SelectedValue == null)
            {
                MessageBox.Show("Выберите блюдо", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            _logger.LogInformation("Создание заказа");
            try
            {
                var operationResult = _logicO.CreateOrder(new OrderBindingModel
                {
                    SushiId = Convert.ToInt32(comboBoxSushi.SelectedValue),
                    ClientId = Convert.ToInt32(comboBoxClient.SelectedValue),
                    EmployeeId = Convert.ToInt32(comboBoxEmployee.SelectedValue),
                    Count = Convert.ToInt32(textBoxCount.Text),
                    Sum = Convert.ToDouble(textBoxSum.Text),
                    Time = DateTime.UtcNow
                });
                if (!operationResult)
                {
                    throw new Exception("Ошибка при создании заказа. Дополнительная информация в логах.");
                }
                MessageBox.Show("Сохранение прошло успешно", "Сообщение", MessageBoxButtons.OK, MessageBoxIcon.Information);
                DialogResult = DialogResult.OK;
                Close();
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка создания заказа");
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void ButtonCancel_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
            Close();
        }
    }
}
