using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;
using NLog.Extensions.Logging;
using SushiBusinessLogic;
using SushiContracts.BusinessLogicContracts;
using SushiContracts.BusinessLogicsContracts;
using SushiContracts.StorageContracts;
using SushiContracts.StoragesContracts;
using SushiDatabaseImplement.implements;
using SushiDatabaseImplement.Implements;
using SushiShopBusinessLogic;
using SushiShopDatabaseImplement.Implements;

namespace Sushi
{
    internal static class Program
    {
        private static ServiceProvider? _serviceProvider;
        public static ServiceProvider? ServiceProvider => _serviceProvider;
        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            // To customize application configuration such as set high DPI settings or default font,
            // see https://aka.ms/applicationconfiguration.
            ApplicationConfiguration.Initialize();
            var services = new ServiceCollection();
            ConfigureServices(services);
            _serviceProvider = services.BuildServiceProvider();
            Application.Run(_serviceProvider.GetRequiredService<FormMain>());
        }
        private static void ConfigureServices(ServiceCollection services)
        {
            services.AddLogging(option =>
            {
                option.SetMinimumLevel(LogLevel.Information);
                option.AddNLog("nlog.config");
            });
            services.AddTransient<IComponentLogic, ComponentLogic>();
            services.AddTransient<IClientLogic, ClientLogic>();
            services.AddTransient<ISushiLogic, SushiLogic>();
            services.AddTransient<IEmployeeLogic, EmployeeLogic>();
            services.AddTransient<IOrderLogic, OrderLogic>();
            services.AddTransient<IClientStorage, ClientStorage>();
            services.AddTransient<IEmployeeStorage, EmployeeStorage>();
            services.AddTransient<IComponentStorage, ComponentStorage>();
            services.AddTransient<ISushiStorage, SushiStorage>();
            services.AddTransient<IOrderStorage, OrderStorage>();
            services.AddTransient<FormComponent>();
            services.AddTransient<FormComponents>();
            services.AddTransient<FormClient>();
            services.AddTransient<FormClients>();
            services.AddTransient<FormEmployee>();
            services.AddTransient<FormEmployees>();
            services.AddTransient<FormCreateOrder>();
            services.AddTransient<FormSushies>();
            services.AddTransient<FormSushi>();
            services.AddTransient<FormMain>();
            services.AddTransient<FormSushiComponent>();
        }
    }
}