﻿using SushiContracts.BindingModels;
using SushiContracts.ViewModels;
using SushiDataModels;
using System.ComponentModel.DataAnnotations.Schema;
using System.ComponentModel.DataAnnotations;
using SushiShopDatabaseImplement.Models;

namespace SushiDatabaseImplement.Models
{
    public class Component : IComponentModel
    {
        public int Id { get; private set; }
        [Required]
        public string ComponentName { get; private set; } = string.Empty;
        [Required]
        public int ComponentPrice { get; private set; }

        [ForeignKey("ComponentId")]
        public virtual List<SushiComponent> SushiComponents { get; set; } = new();

        public static Component? Create(ComponentBindingModel model)
        {
            if (model == null)
            {
                return null;
            }
            return new Component()
            {
                Id = model.Id,
                ComponentName = model.ComponentName,
                ComponentPrice = model.ComponentPrice
            };
        }

        public static Component Create(ComponentViewModel model)
        {
            return new Component()
            {
                Id = model.Id,
                ComponentName = model.ComponentName,
                ComponentPrice = model.ComponentPrice
            };
        }

        public void Update(ComponentBindingModel model)
        {
            if (model == null)
            {
                return;
            }
            ComponentName = model.ComponentName;
            ComponentPrice = model.ComponentPrice;
        }

        public ComponentViewModel GetViewModel => new()
        {
            Id = Id,
            ComponentName = ComponentName,
            ComponentPrice = ComponentPrice
        };
    }
}
